from bs4.element import Tag, ResultSet
from bs4 import BeautifulSoup
from selenium import webdriver

driver = webdriver.Chrome()


def get_url(year: int, month: int):
    return f"https://nepalipatro.com.np/calendar/monthly/bs/{year}/{month}"


nepali_to_english_digits = {
    "१": 1,
    "२": 2,
    "३": 3,
    "४": 4,
    "५": 5,
    "६": 6,
    "७": 7,
    "८": 8,
    "९": 9,
    "१०": 10,
    "११": 11,
    "१२": 12,
    "१३": 13,
    "१४": 14,
    "१५": 15,
    "१६": 16,
    "१७": 17,
    "१८": 18,
    "१९": 19,
    "२०": 20,
    "२१": 21,
    "२२": 22,
    "२३": 23,
    "२४": 24,
    "२५": 25,
    "२६": 26,
    "२७": 27,
    "२८": 28,
    "२९": 29,
    "३०": 30,
    "३१": 31,
    "३२": 32,
}


def get_months(year: int):
    months: list[int] = []

    for month in range(1, 13):
        url = get_url(year, month)
        while True:
            driver.get(url)

            soup = BeautifulSoup(driver.page_source, "html.parser")
            calendar = soup.find("div", {"class": "calendar"})

            if isinstance(calendar, Tag):
                month_divs: list[Tag] = []
                for div in calendar.find_all("div", attrs={"class": True}):
                    div_class = div["class"]

                    if (
                        "col" in div_class
                        and "cell" in div_class
                        and "other-month" not in div_class
                    ):
                        month_divs.append(div)

                month_div = month_divs[-1]

                month_count = nepali_to_english_digits[
                    month_div.find("span", {"class": "text"}).text  # type:ignore
                ]
                months.append(month_count)
                break

    return months


for year in range(2100, 2201):
    months = get_months(year)
    months.insert(0, sum(months))
    print(f"{year}: {months},")
